Logo and corporate identity — mosaik 2.2.0 documentation

# Logo and corporate identity

This page contains download links to the mosaik logos and lists the official mosaik colors.

## Normal logo

This is the large version of the logo.

### PNG, 1920 × 1052 px, with transparency

### SVG for the web

Letters converted to objects so that it nicely renders on all devices.

### SVG for Inkscape

This is the Inkscape master file for the logo. In order to edit it in Inkscape, you need to install the Aller font.

## Simple logo

The simple variant of the logo should be used when the display size for the logo is so small, that the icons would not be recognizable very well, e.g. in the headers of letters or papers.

### PNG, 512 × 280 px, with transparency

### SVG for the web

Letters converted to objects so that it nicely renders on all devices.

### SVG for Inkscape

This is the Inkscape master file for the logo. In order to edit it in Inkscape, you need to install the Aller font.

## Icon

This version should be used for (program) Icons.

### PNG, 512 × 512 px, with transparency

### SVG

## Colors

Value ranges RGB:
  [0-255] [0-255] [0-255]
Value ranges HSB/HSL:
  [0-359]° [0-100]% [0-100]%

### mosaik logo

These colors are usually only used in the logo.

Mod. | Green | Orange | Red | Purple | Blue | Gray
--- | --- | --- | --- | --- | --- | ---
CMYK | 28 0 70 49 | 0 35 75 15 | 0 85 85 28 | 0 60 0 43 | 70 21 0 12 | 0 0 0 72
RGB | 94 130 39 | 217 141 54 | 184 28 28 | 145 58 145 | 59 154 196 | 72 72 72
LAB | 50 -27 43 | 65 22 56 | 40 59 42 | 40 48 -31 | 60 -14 -30 | 31 0 0
HSB | 84 70 51 | 32 75 85 | 0 85 72 | 300 60 57 | 198 70 77 | 0 0 28
HSL | 84 54 33 | 32 68 53 | 0 74 42 | 300 43 30 | 198 54 50 | 0 0 28
HEX | #5E8227 | #D98D36 | #B81C1C | #913A91 | #3B9AC4 | #484848

### mosaik dark

These colors are usually used for figures, diagrams and in presentations.

Mod. | Green | Orange | Red | Purple | Blue | Gray
--- | --- | --- | --- | --- | --- | ---
CMYK | 28 0 70 49 | 0 37 81 34 | 0 80 80 29 | 0 60 0 43 | 70 21 0 50 | 0 0 0 72
RGB | 94 130 39 | 168 105 32 | 181 36 36 | 145 58 145 | 38 101 128 | 72 72 72
LAB | 50 -27 43 | 50 19 49 | 40 56 38 | 40 48 -31 | 40 -11 -21 | 31 0 0
HSB | 84 70 51 | 32 81 66 | 0 80 71 | 300 60 57 | 198 70 50 | 0 0 28
HSL | 84 54 33 | 32 68 39 | 0 67 43 | 300 43 30 | 198 54 33 | 0 0 28
HEX | #5E8227 | #A86920 | #B52424 | #913A91 | #266580 | #484848